Known Hosts Management
Handles verification and storage of host keys for TOFU (Trust On First Use)
Structs
- HostKey
- A host key entry
- Known
Hosts - Known hosts database
Enums
- Verification
Result - Result of host key verification
Known Hosts Management
Handles verification and storage of host keys for TOFU (Trust On First Use)